<?php

namespace Albaraha\Hospital\Policies;

use Litepie\User\Contracts\UserPolicy;
use Albaraha\Hospital\Models\Hospital;

class HospitalPolicy
{

    /**
     * Determine if the given user can view the hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hospital $hospital)
    {
        if ($user->canDo('hospital.hospital.view') && $user->isAdmin()) {
            return true;
        }

        return $hospital->user_id == user_id() && $hospital->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hospital.hospital.create');
    }

    /**
     * Determine if the given user can update the given hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hospital $hospital)
    {
        if ($user->canDo('hospital.hospital.edit') && $user->isAdmin()) {
            return true;
        }

        return $hospital->user_id == user_id() && $hospital->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hospital $hospital)
    {
        return $hospital->user_id == user_id() && $hospital->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hospital $hospital)
    {
        if ($user->canDo('hospital.hospital.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hospital.
     *
     * @param UserPolicy $user
     * @param Hospital $hospital
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hospital $hospital)
    {
        if ($user->canDo('hospital.hospital.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
